@@ -49,7 +49,7 @@ use PPIx::Regexp::Constant qw{
     TRUE
 };
 
-our $VERSION = '0.053';
+our $VERSION = '0.054';
 
 =head2 accepts_perl
 
@@ -454,6 +454,27 @@ sub requirements_for_perl {
     return join ' || ', @req;
 }
 
+=head2 scontent
+
+This method returns the significant content of the element. That is, if
+called on the parse of C<'/ f u b a r /x'>, it returns C<'/fubar/x'>. If
+the invocant contains no insignificant elements, it is the same as
+L<content()|/content>. If called on an insignificant element, it returns
+nothing -- that is, C<undef> in scalar context, and an empty list in
+list context.
+
+This method was inspired by jb's question on Perl Monks about stripping
+comments and white space from a regular expression:
+L<http://www.perlmonks.org/?node_id=1207556>
+
+This method was added in version 0.053_01
+
+=cut
+
+sub scontent {
+    return;
+}
+
 =head2 significant
 
 This method returns true if the element is significant and false
@@ -717,7 +738,7 @@ Thomas R. Wyant, III F<wyant at cpan dot org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2009-2017 by Thomas R. Wyant, III
+Copyright (C) 2009-2018 by Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
