@@ -1,4 +1,6 @@
-package PPIx::Regexp::Structure::Script_Run;
+# Cargo cult to try to prevent CPAN from indexing
+package
+PPIx::Regexp::Structure::Script_Run;
 
 use 5.006;
 
@@ -7,9 +9,10 @@ use warnings;
 
 use base qw{ PPIx::Regexp::Structure };
 
-use PPIx::Regexp::Constant qw{ @CARP_NOT };
+use Carp;
+
+our $VERSION = '0.054';
 
-our $VERSION = '0.090_02';
 
 1;
 
@@ -22,7 +25,7 @@ PPIx::Regexp::Structure::Script_Run - Represent a script run group
 =head1 SYNOPSIS
 
  use PPIx::Regexp::Dumper;
- PPIx::Regexp::Dumper->new( 'qr{(*script_run:\d)}' )
+ PPIx::Regexp::Dumper->new( 'qr{(+script_run:\d)}' )
      ->print();
 
 =head1 INHERITANCE
@@ -35,9 +38,7 @@ C<PPIx::Regexp::Structure::Script_Run> has no descendants.
 =head1 DESCRIPTION
 
 This class represents a script run group. That is, the construction
-C<(+script_run:...)>, C<(*script_run:...)>, or C<(*sr:...)>. The first
-form was added in Perl 5.27.8 but retracted in favor of the second ant
-third forms (which are equivalent) in Perl 5.27.9.
+C<(+script_run:...)>. This is new with Perl 5.27.8.
 
 If this construction does not make it into Perl 5.28, this class will be
 retracted.
@@ -50,9 +51,7 @@ superclass.
 =head1 SUPPORT
 
 Support is by the author. Please file bug reports at
-L<https://rt.cpan.org/Public/Dist/Display.html?Name=PPIx-Regexp>,
-L<https://github.com/trwyant/perl-PPIx-Regexp/issues>, or in
-electronic mail to the author.
+L<http://rt.cpan.org>, or in electronic mail to the author.
 
 =head1 AUTHOR
 
@@ -60,7 +59,7 @@ Thomas R. Wyant, III F<wyant at cpan dot org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2018-2023, 2025 by Thomas R. Wyant, III
+Copyright (C) 2018 by Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
