@@ -1,4 +1,6 @@
-package PPIx::Regexp::Token::GroupType::Script_Run;
+# Cargo cult to try to prevent CPAN from indexing
+package
+PPIx::Regexp::Token::GroupType::Script_Run;
 
 use 5.006;
 
@@ -7,29 +9,23 @@ use warnings;
 
 use base qw{ PPIx::Regexp::Token::GroupType };
 
-use PPIx::Regexp::Constant qw{ @CARP_NOT };
+use Carp;
 
-our $VERSION = '0.090_02';
+our $VERSION = '0.054';
 
-use constant EXPL => 'All characters must be in same script';
+sub __explanation {
+    return {
+	'+script_run:'	=> 'All characters must be in same script',
+    };
+}
 
-use constant DEF	=> {
-    '+script_run:'	=> {
-	expl	=> EXPL,
-	intro	=> '5.027008',
-	remov	=> '5.027009',
-    },
-    '*script_run:'	=> {
-	expl	=> EXPL,
-	intro	=> '5.027009',
-    },
-    '*sr:'	=> {
-	expl	=> EXPL,
-	intro	=> '5.027009',
-    },
-};
+sub perl_version_introduced {
+    return '5.027008';
+}
 
-__PACKAGE__->__setup_class();
+sub __defining_string {
+    return '+script_run:';
+}
 
 1;
 
@@ -42,7 +38,7 @@ PPIx::Regexp::Token::GroupType::Script_Run - Represent a script run specifier
 =head1 SYNOPSIS
 
  use PPIx::Regexp::Dumper;
- PPIx::Regexp::Dumper->new( 'qr{(*script_run:\d)}' )
+ PPIx::Regexp::Dumper->new( 'qr{(+script_run:\d)}' )
      ->print();
 
 =head1 INHERITANCE
@@ -55,10 +51,8 @@ C<PPIx::Regexp::Token::GroupType::Script_Run> has no descendants.
 =head1 DESCRIPTION
 
 This token represents the specifier for a script run - namely the
-C<'+script_run:'>, C<'*script_run:'>, or C<'*sr:'> that comes after the
-left parenthesis. The first form was added in Perl 5.27.8 but retracted
-in favor of the second ant third forms (which are equivalent) in Perl
-5.27.9.
+C<'+script_run:'> that comes after the left parenthesis. This is new
+with Perl 5.27.8.
 
 If this construction does not make it into Perl 5.28, this class will be
 retracted.
@@ -71,9 +65,7 @@ superclass.
 =head1 SUPPORT
 
 Support is by the author. Please file bug reports at
-L<https://rt.cpan.org/Public/Dist/Display.html?Name=PPIx-Regexp>,
-L<https://github.com/trwyant/perl-PPIx-Regexp/issues>, or in
-electronic mail to the author.
+L<http://rt.cpan.org>, or in electronic mail to the author.
 
 =head1 AUTHOR
 
@@ -81,7 +73,7 @@ Thomas R. Wyant, III F<wyant at cpan dot org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2018-2023, 2025 by Thomas R. Wyant, III
+Copyright (C) 2018 by Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
